@@ -25,13 +25,25 @@ enum class CandidateLayoutHint { NotSet, Vertical, Horizontal };
 
 class CandidateWordPrivate;
 
+/// Base class of candidate word.
 class FCITXCORE_EXPORT CandidateWord {
 public:
     CandidateWord(Text text = {});
     virtual ~CandidateWord();
+    /**
+     * Called when candidate is selected by user.
+     *
+     * @param inputContext the associated input context for the candidate.
+     */
     virtual void select(InputContext *inputContext) const = 0;
 
     const Text &text() const;
+    /**
+     * Whether the candidate is only a place holder.
+     *
+     * If candidate is a place holder, it will not be displayed by UI, but it
+     * will still take one place in the candidate list.
+     */
     bool isPlaceHolder() const;
     bool hasCustomLabel() const;
     const Text &customLabel() const;
@@ -59,6 +71,8 @@ public:
     virtual int cursorIndex() const = 0;
     virtual CandidateLayoutHint layoutHint() const = 0;
 
+    bool empty() const;
+
     PageableCandidateList *toPageable() const;
     BulkCandidateList *toBulk() const;
     ModifiableCandidateList *toModifiable() const;
@@ -158,7 +172,7 @@ private:
 
 class CommonCandidateListPrivate;
 
-enum CursorPositionAfterPaging { SameAsLast, DonotChange, ResetToFirst };
+enum class CursorPositionAfterPaging { SameAsLast, DonotChange, ResetToFirst };
 
 class FCITXCORE_EXPORT CommonCandidateList : public CandidateList,
                                              public PageableCandidateList,
@@ -171,6 +185,7 @@ public:
     void clear();
     void setSelectionKey(const KeyList &keyList);
     void setPageSize(int size);
+    int pageSize() const;
     void setLayoutHint(CandidateLayoutHint hint);
     void setGlobalCursorIndex(int index);
 
